searchData={"content_type":"text/markdown","items":[{"doc":"Off Broadway Elasticsearch Producer.","ref":"OffBroadway.Elasticsearch.html","title":"OffBroadway.Elasticsearch","type":"module"},{"doc":"A keyword list of all Broadway options / state","ref":"OffBroadway.Elasticsearch.html#t:broadway_state/0","title":"OffBroadway.Elasticsearch.broadway_state/0","type":"type"},{"doc":"A Elasticsearch document represented as a Map. To allow maximum control, the\nentire document is returned, including metadata along with the `_source`.","ref":"OffBroadway.Elasticsearch.html#t:document/0","title":"OffBroadway.Elasticsearch.document/0","type":"type"},{"doc":"A GenStage producer that continuously fetches documents from Elasticsearch\nbased on the configured strategy.\n\nStrategies are meant to provide flexibility based on your use case. The\ncurrent strategies are:\n\n- `OffBroadway.Elasticsearch.SearchAfterStrategy` - Docs: [Search After](https://www.elastic.co/guide/en/elasticsearch/reference/8.13/paginate-search-results.html#search-after)\n- `OffBroadway.Elasticsearch.ScrollStrategy`- Docs: [Scroll Search](https://www.elastic.co/guide/en/elasticsearch/reference/8.13/paginate-search-results.html#scroll-search-results)\n- `OffBroadway.Elasticsearch.SliceStrategy` - Docs: [Sliced Scroll](https://www.elastic.co/guide/en/elasticsearch/reference/8.13/paginate-search-results.html#slice-scroll)\n\n**The available options are:**\n\n- `host:` (`String.t()`) - Required. The host where Elasticsearch can be found.\n- `index:` (`String.t()`) - Required. The index to be ingested.\n- `search:` (`Map.t()`) - Required. The search payload to be sent to Elasticsearch.\n- `strategy:` (`Atom.t()`) - One of:\n    - [`:search_after`](`OffBroadway.Elasticsearch.SearchAfterStrategy`)\n    - [`:scroll`](`OffBroadway.Elasticsearch.ScrollStrategy`)\n    - [`:slice`](`OffBroadway.Elasticsearch.SliceStrategy`)\n- `strategy_module:` (`Atom.t()`). A custom module that implemments\n`OffBroadway.Elasticsearch.Strategy` to be used if any of the built in\nstrategies don't fit your use case.","ref":"OffBroadway.Elasticsearch.Producer.html","title":"OffBroadway.Elasticsearch.Producer","type":"module"},{"doc":"```\ndefmodule MyBroadway do\n  use Broadway\n\n  def start_link(_opts) do\n    Broadway.start_link(__MODULE__,\n      name: __MODULE__,\n      producer: [\n        module: {\n          OffBroadway.Elasticsearch.Producer,\n          [\n            # The options listed above.\n            host: \"http://localhost:9200\",\n            index: \"my-index\",\n            strategy: :slice,\n            # If `strategy_module` is provided, it will take precedence over\n            # `strategy`, that can be omitted when providing this option.\n            strategy_module: MySearchStrategy\n            search: search() # Extracted to a private function below.\n          ]\n        },\n        transformer: {__MODULE__, :transform, []},\n        concurrency: 10\n      ],\n      processors: [\n        default: [concurrency: 5]\n      ]\n    )\n  end\n\n  defp search do\n    %{\n      query: %{\n        match_all: %{}\n      },\n      sort: %{\n        created_at: \"asc\",\n        _id: \"asc\"\n      }\n    }\n  end\nend\n```","ref":"OffBroadway.Elasticsearch.Producer.html#module-example","title":"Example: - OffBroadway.Elasticsearch.Producer","type":"module"},{"doc":"","ref":"OffBroadway.Elasticsearch.Producer.html#handle_demand/2","title":"OffBroadway.Elasticsearch.Producer.handle_demand/2","type":"function"},{"doc":"","ref":"OffBroadway.Elasticsearch.Producer.html#init/1","title":"OffBroadway.Elasticsearch.Producer.init/1","type":"function"},{"doc":"The available options are:\n\n- `host:` (`String.t()`) - Required. The host where Elasticsearch can be found.\n- `index:` (`String.t()`) - Required. The index to be ingested.\n- `search:` (`Map.t()`) - Required. The search payload to be sent to Elasticsearch.\n- `strategy:` (`Atom.t()`) - One of:\n    - [`:search_after`](`OffBroadway.Elasticsearch.SearchAfterStrategy`)\n    - [`:scroll`](`OffBroadway.Elasticsearch.ScrollStrategy`)\n    - [`:slice`](`OffBroadway.Elasticsearch.SliceStrategy`)\n- `strategy_module:` (`Atom.t()`). A custom module that implements\n`OffBroadway.Elasticsearch.Strategy` to be used if any of the built in\nstrategies don't fit your use case.","ref":"OffBroadway.Elasticsearch.Producer.html#start_link/1","title":"OffBroadway.Elasticsearch.Producer.start_link/1","type":"function"},{"doc":"Implementation of `OffBroadway.Elasticsearch.Strategy` that uses the \"Scroll\"\nfeature of Elasticsearch. This strategy is best suited for a single producer,\nfetching less than `10,000` results per request. For concurrent searching, see\n`OffBroadway.Elasticsearch.SliceStrategy` and for searching with demand\ngreater than `10,000` see `OffBroadway.Elasticsearch.SearchAfterStrategy`","ref":"OffBroadway.Elasticsearch.ScrollStrategy.html","title":"OffBroadway.Elasticsearch.ScrollStrategy","type":"module"},{"doc":"```\ndefmodule MyBroadway do\n  use Broadway\n\n  def start_link(_opts) do\n    Broadway.start_link(__MODULE__,\n      ...\n      producer: [\n        module: {\n          OffBroadway.Elasticsearch.Producer,\n          [\n            host: \"http://localhost:9200\",\n            index: \"my-index\",\n            strategy: :scroll, # <- Select the 'scroll' strategy\n            search: search() # <- Provide a search query\n          ]\n        },\n        concurrency: 1 # <- A single process to manage 'scrolling'\n      ],\n      ...\n    )\n  end\nend\n```\n\nSee Elasticsearch docs: [Scroll Search](https://www.elastic.co/guide/en/elasticsearch/reference/8.13/paginate-search-results.html#scroll-search-results)","ref":"OffBroadway.Elasticsearch.ScrollStrategy.html#module-example","title":"Example - OffBroadway.Elasticsearch.ScrollStrategy","type":"module"},{"doc":"","ref":"OffBroadway.Elasticsearch.ScrollStrategy.html#t:broadway_state/0","title":"OffBroadway.Elasticsearch.ScrollStrategy.broadway_state/0","type":"type"},{"doc":"","ref":"OffBroadway.Elasticsearch.ScrollStrategy.html#t:document/0","title":"OffBroadway.Elasticsearch.ScrollStrategy.document/0","type":"type"},{"doc":"Implementation of `OffBroadway.Elasticsearch.Strategy` that's able to fetch\nmore than `10,000` results per request by using Elasticsearch's `search_after`\nfeature. This strategy is best suited for a single producer and the\nsearch query must be sorted in some way. For concurrent searching, see\n`OffBroadway.Elasticsearch.SliceStrategy`","ref":"OffBroadway.Elasticsearch.SearchAfterStrategy.html","title":"OffBroadway.Elasticsearch.SearchAfterStrategy","type":"module"},{"doc":"```\ndefmodule MyBroadway do\n  use Broadway\n\n  def start_link(_opts) do\n    Broadway.start_link(__MODULE__,\n      ...\n      producer: [\n        module: {\n          OffBroadway.Elasticsearch.Producer,\n          [\n            host: \"http://localhost:9200\",\n            index: \"my-index\",\n            strategy: :search_after, # <- Select the 'search_after' strategy\n            search: search() # <- Provide a search query\n          ]\n        },\n        concurrency: 1 # <- Best\n      ],\n      ...\n    )\n  end\n\n  def search do\n    %{\n      query: %{\n        match_all: %{}\n      },\n      sort: %{ # <- Must be present so Elasticsearch returns the `search_after` keys/values\n        created_at: \"asc\",\n        _id: \"asc\"\n      }\n    }\n  end\nend\n```\nSee Elasticsearch docs: [Search After](https://www.elastic.co/guide/en/elasticsearch/reference/8.13/paginate-search-results.html#search-after)","ref":"OffBroadway.Elasticsearch.SearchAfterStrategy.html#module-example","title":"Example - OffBroadway.Elasticsearch.SearchAfterStrategy","type":"module"},{"doc":"","ref":"OffBroadway.Elasticsearch.SearchAfterStrategy.html#t:broadway_state/0","title":"OffBroadway.Elasticsearch.SearchAfterStrategy.broadway_state/0","type":"type"},{"doc":"","ref":"OffBroadway.Elasticsearch.SearchAfterStrategy.html#t:document/0","title":"OffBroadway.Elasticsearch.SearchAfterStrategy.document/0","type":"type"},{"doc":"Implementation of `OffBroadway.Elasticsearch.Strategy` that's suitable\nfor concurrent reading. Slices are determined by the `concurrency`\noption passed into the Broadway producer\noptions.","ref":"OffBroadway.Elasticsearch.SliceStrategy.html","title":"OffBroadway.Elasticsearch.SliceStrategy","type":"module"},{"doc":"```\ndefmodule MyBroadway do\n  use Broadway\n\n  def start_link(_opts) do\n    Broadway.start_link(__MODULE__,\n      ...\n      producer: [\n        module: {\n          OffBroadway.Elasticsearch.Producer,\n          [\n            host: \"http://localhost:9200\",\n            index: \"my-index\",\n            strategy: :slice, # <- Select the 'slice' strategy\n            search: search() # <- Provide a search query\n          ]\n        },\n        concurrency: 5 # <- Determines the max number of sliced search contexts to be created\n      ],\n      ...\n    )\n  end\nend\n```\n\nSee Elasticsearch docs: [Sliced Scroll](https://www.elastic.co/guide/en/elasticsearch/reference/8.13/paginate-search-results.html#slice-scroll)","ref":"OffBroadway.Elasticsearch.SliceStrategy.html#module-example","title":"Example - OffBroadway.Elasticsearch.SliceStrategy","type":"module"},{"doc":"","ref":"OffBroadway.Elasticsearch.SliceStrategy.html#t:broadway_state/0","title":"OffBroadway.Elasticsearch.SliceStrategy.broadway_state/0","type":"type"},{"doc":"","ref":"OffBroadway.Elasticsearch.SliceStrategy.html#t:document/0","title":"OffBroadway.Elasticsearch.SliceStrategy.document/0","type":"type"},{"doc":"Elasticseach supports many strategies for efficiently searching over large\namounts of data, by adopting a strategy pattern, different strategies can be\ncreated and configured depending on the use case.\n\nTo learn more about other strategies see Elasticsearch docs: [Paginating Search Results](https://www.elastic.co/guide/en/elasticsearch/reference/8.13/paginate-search-results.html#paginate-search-results)","ref":"OffBroadway.Elasticsearch.Strategy.html","title":"OffBroadway.Elasticsearch.Strategy","type":"behaviour"},{"doc":"Optionally called after `execute` with the current `broadway_state()` and the\nresults of `execute`, a list of `document()`. Depending on the search strategy\nused, Elasticsearch can return _new_ state that needs to be used in the next\nrequest. For example, the `ScrollSearch` strategy must pass the current\n`scroll_id` to the next request to return the next batch of results.","ref":"OffBroadway.Elasticsearch.Strategy.html#c:after_execute/2","title":"OffBroadway.Elasticsearch.Strategy.after_execute/2","type":"callback"},{"doc":"Optionally called _before_ the strategy is executed. It's often\nnecessary to modify search parameters or other state of the producer before\nrequests are sent to Elasticsearch.","ref":"OffBroadway.Elasticsearch.Strategy.html#c:before_execute/2","title":"OffBroadway.Elasticsearch.Strategy.before_execute/2","type":"callback"},{"doc":"Called immediately after `before_execute` with the modified `broadway_state()`.\nThis function should make the request to Elasticsearch to satisfy demand.","ref":"OffBroadway.Elasticsearch.Strategy.html#c:execute/1","title":"OffBroadway.Elasticsearch.Strategy.execute/1","type":"callback"},{"doc":"A keyword list of all Broadway options/state","ref":"OffBroadway.Elasticsearch.Strategy.html#t:broadway_state/0","title":"OffBroadway.Elasticsearch.Strategy.broadway_state/0","type":"type"},{"doc":"A Elasticsearch document represented as a Map. To allow maximum control, the\nentire document is returned, including metadata along with the `_source`.","ref":"OffBroadway.Elasticsearch.Strategy.html#t:document/0","title":"OffBroadway.Elasticsearch.Strategy.document/0","type":"type"},{"doc":"# OffBroadway.Elasticsearch\n\nA flexible and extensible Elasticsearch producer for [Broadway](https://github.com/plataformatec/broadway) to process large amounts of data from your Elasticsearch cluster.\n\nFull documentation can be found at https://hexdocs.pm/off_broadway_elasticsearch\n\nThis project provides:","ref":"readme.html","title":"OffBroadway.Elasticsearch","type":"extras"},{"doc":"`OffBroadway.Elasticsearch.Producer`\n\nA GenStage producer that continuously fetches documents from Elasticsearch based on the configured strategy.","ref":"readme.html#producer","title":"Producer - OffBroadway.Elasticsearch","type":"extras"},{"doc":"Strategies are meant to provide flexibility based on your use case. The current strategies are:\n\n- `OffBroadway.Elasticsearch.SearchAfterStrategy` - Docs: [Search After](https://www.elastic.co/guide/en/elasticsearch/reference/8.13/paginate-search-results.html#search-after)\n- `OffBroadway.Elasticsearch.ScrollStrategy`- Docs: [Scroll Search](https://www.elastic.co/guide/en/elasticsearch/reference/8.13/paginate-search-results.html#scroll-search-results)\n- `OffBroadway.Elasticsearch.SliceStrategy` - Docs: [Sliced Scroll](https://www.elastic.co/guide/en/elasticsearch/reference/8.13/paginate-search-results.html#slice-scroll)\n\nIf any of the built strategies don't fit your use case you can provide your own\nimplementation of `OffBroadway.Elasticsearch.Strategy` and pass it to the\nproducer via the `strategy_module:` option.","ref":"readme.html#search-strategies","title":"Search Strategies - OffBroadway.Elasticsearch","type":"extras"},{"doc":"Add `off_broadway_elasticsearch` to the list of dependences in your `mix.exs` file:\n\n```elixir\ndef deps do\n  [\n    {:off_broadway_elasticsearch, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - OffBroadway.Elasticsearch","type":"extras"},{"doc":"**The available options are:**\n\n- `host:` (`String.t()`) - Required. The host where Elasticsearch can be found.\n- `index:` (`String.t()`) - Required. The index to be ingested.\n- `search:` (`Map.t()`) - Required. The search payload to be sent to Elasticsearch.\n- `strategy:` (`Atom.t()`) - One of:\n  - [`:search_after`](`OffBroadway.Elasticsearch.SearchAfterStrategy`)\n  - [`:scroll`](`OffBroadway.Elasticsearch.ScrollStrategy`)\n  - [`:slice`](`OffBroadway.Elasticsearch.SliceStrategy`)\n- `strategy_module:` (`Atom.t()`). A custom module that implements\n  `OffBroadway.Elasticsearch.Strategy` to be used if any of the built in\n  strategies don't fit your use case.","ref":"readme.html#usage","title":"Usage - OffBroadway.Elasticsearch","type":"extras"},{"doc":"```\ndefmodule MyBroadway do\n  use Broadway\n\n  def start_link(_opts) do\n    Broadway.start_link(__MODULE__,\n      name: __MODULE__,\n      producer: [\n        module: {\n          OffBroadway.Elasticsearch.Producer,\n          [\n            # The options listed above.\n            host: \"http://localhost:9200\",\n            index: \"my-index\",\n            strategy: :slice,\n            # If `strategy_module` is provided, it will take precedence over\n            # `strategy`, that can be omitted when providing this option.\n            strategy_module: MySearchStrategy\n            search: search() # Extracted to a private function below.\n          ]\n        },\n        transformer: {__MODULE__, :transform, []},\n        concurrency: 10\n      ],\n      processors: [\n        default: [concurrency: 5]\n      ]\n    )\n  end\n\n  defp search do\n    %{\n      query: %{\n        match_all: %{}\n      },\n      sort: %{\n        created_at: \"asc\",\n        _id: \"asc\"\n      }\n    }\n  end\nend\n```","ref":"readme.html#example","title":"Example: - OffBroadway.Elasticsearch","type":"extras"},{"doc":"# License\n\nApache License\nVersion 2.0, January 2004\nhttp://www.apache.org/licenses/\n\nTERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n1.  Definitions.\n\n    \"License\" shall mean the terms and conditions for use, reproduction,\n    and distribution as defined by Sections 1 through 9 of this document.\n\n    \"Licensor\" shall mean the copyright owner or entity authorized by\n    the copyright owner that is granting the License.\n\n    \"Legal Entity\" shall mean the union of the acting entity and all\n    other entities that control, are controlled by, or are under common\n    control with that entity. For the purposes of this definition,\n    \"control\" means (i) the power, direct or indirect, to cause the\n    direction or management of such entity, whether by contract or\n    otherwise, or (ii) ownership of fifty percent (50%) or more of the\n    outstanding shares, or (iii) beneficial ownership of such entity.\n\n    \"You\" (or \"Your\") shall mean an individual or Legal Entity\n    exercising permissions granted by this License.\n\n    \"Source\" form shall mean the preferred form for making modifications,\n    including but not limited to software source code, documentation\n    source, and configuration files.\n\n    \"Object\" form shall mean any form resulting from mechanical\n    transformation or translation of a Source form, including but\n    not limited to compiled object code, generated documentation,\n    and conversions to other media types.\n\n    \"Work\" shall mean the work of authorship, whether in Source or\n    Object form, made available under the License, as indicated by a\n    copyright notice that is included in or attached to the work\n    (an example is provided in the Appendix below).\n\n    \"Derivative Works\" shall mean any work, whether in Source or Object\n    form, that is based on (or derived from) the Work and for which the\n    editorial revisions, annotations, elaborations, or other modifications\n    represent, as a whole, an original work of authorship. For the purposes\n    of this License, Derivative Works shall not include works that remain\n    separable from, or merely link (or bind by name) to the interfaces of,\n    the Work and Derivative Works thereof.\n\n    \"Contribution\" shall mean any work of authorship, including\n    the original version of the Work and any modifications or additions\n    to that Work or Derivative Works thereof, that is intentionally\n    submitted to Licensor for inclusion in the Work by the copyright owner\n    or by an individual or Legal Entity authorized to submit on behalf of\n    the copyright owner. For the purposes of this definition, \"submitted\"\n    means any form of electronic, verbal, or written communication sent\n    to the Licensor or its representatives, including but not limited to\n    communication on electronic mailing lists, source code control systems,\n    and issue tracking systems that are managed by, or on behalf of, the\n    Licensor for the purpose of discussing and improving the Work, but\n    excluding communication that is conspicuously marked or otherwise\n    designated in writing by the copyright owner as \"Not a Contribution.\"\n\n    \"Contributor\" shall mean Licensor and any individual or Legal Entity\n    on behalf of whom a Contribution has been received by Licensor and\n    subsequently incorporated within the Work.\n\n2.  Grant of Copyright License. Subject to the terms and conditions of\n    this License, each Contributor hereby grants to You a perpetual,\n    worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n    copyright license to reproduce, prepare Derivative Works of,\n    publicly display, publicly perform, sublicense, and distribute the\n    Work and such Derivative Works in Source or Object form.\n\n3.  Grant of Patent License. Subject to the terms and conditions of\n    this License, each Contributor hereby grants to You a perpetual,\n    worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n    (except as stated in this section) patent license to make, have made,\n    use, offer to sell, sell, import, and otherwise transfer the Work,\n    where such license applies only to those patent claims licensable\n    by such Contributor that are necessarily infringed by their\n    Contribution(s) alone or by combination of their Contribution(s)\n    with the Work to which such Contribution(s) was submitted. If You\n    institute patent litigation against any entity (including a\n    cross-claim or counterclaim in a lawsuit) alleging that the Work\n    or a Contribution incorporated within the Work constitutes direct\n    or contributory patent infringement, then any patent licenses\n    granted to You under this License for that Work shall terminate\n    as of the date such litigation is filed.\n\n4.  Redistribution. You may reproduce and distribute copies of the\n    Work or Derivative Works thereof in any medium, with or without\n    modifications, and in Source or Object form, provided that You\n    meet the following conditions:\n\n    (a) You must give any other recipients of the Work or\n    Derivative Works a copy of this License; and\n\n    (b) You must cause any modified files to carry prominent notices\n    stating that You changed the files; and\n\n    (c) You must retain, in the Source form of any Derivative Works\n    that You distribute, all copyright, patent, trademark, and\n    attribution notices from the Source form of the Work,\n    excluding those notices that do not pertain to any part of\n    the Derivative Works; and\n\n    (d) If the Work includes a \"NOTICE\" text file as part of its\n    distribution, then any Derivative Works that You distribute must\n    include a readable copy of the attribution notices contained\n    within such NOTICE file, excluding those notices that do not\n    pertain to any part of the Derivative Works, in at least one\n    of the following places: within a NOTICE text file distributed\n    as part of the Derivative Works; within the Source form or\n    documentation, if provided along with the Derivative Works; or,\n    within a display generated by the Derivative Works, if and\n    wherever such third-party notices normally appear. The contents\n    of the NOTICE file are for informational purposes only and\n    do not modify the License. You may add Your own attribution\n    notices within Derivative Works that You distribute, alongside\n    or as an addendum to the NOTICE text from the Work, provided\n    that such additional attribution notices cannot be construed\n    as modifying the License.\n\n    You may add Your own copyright statement to Your modifications and\n    may provide additional or different license terms and conditions\n    for use, reproduction, or distribution of Your modifications, or\n    for any such Derivative Works as a whole, provided Your use,\n    reproduction, and distribution of the Work otherwise complies with\n    the conditions stated in this License.\n\n5.  Submission of Contributions. Unless You explicitly state otherwise,\n    any Contribution intentionally submitted for inclusion in the Work\n    by You to the Licensor shall be under the terms and conditions of\n    this License, without any additional terms or conditions.\n    Notwithstanding the above, nothing herein shall supersede or modify\n    the terms of any separate license agreement you may have executed\n    with Licensor regarding such Contributions.\n\n6.  Trademarks. This License does not grant permission to use the trade\n    names, trademarks, service marks, or product names of the Licensor,\n    except as required for reasonable and customary use in describing the\n    origin of the Work and reproducing the content of the NOTICE file.\n\n7.  Disclaimer of Warranty. Unless required by applicable law or\n    agreed to in writing, Licensor provides the Work (and each\n    Contributor provides its Contributions) on an \"AS IS\" BASIS,\n    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n    implied, including, without limitation, any warranties or conditions\n    of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n    PARTICULAR PURPOSE. You are solely responsible for determining the\n    appropriateness of using or redistributing the Work and assume any\n    risks associated with Your exercise of permissions under this License.\n\n8.  Limitation of Liability. In no event and under no legal theory,\n    whether in tort (including negligence), contract, or otherwise,\n    unless required by applicable law (such as deliberate and grossly\n    negligent acts) or agreed to in writing, shall any Contributor be\n    liable to You for damages, including any direct, indirect, special,\n    incidental, or consequential damages of any character arising as a\n    result of this License or out of the use or inability to use the\n    Work (including but not limited to damages for loss of goodwill,\n    work stoppage, computer failure or malfunction, or any and all\n    other commercial damages or losses), even if such Contributor\n    has been advised of the possibility of such damages.\n\n9.  Accepting Warranty or Additional Liability. While redistributing\n    the Work or Derivative Works thereof, You may choose to offer,\n    and charge a fee for, acceptance of support, warranty, indemnity,\n    or other liability obligations and/or rights consistent with this\n    License. However, in accepting such obligations, You may act only\n    on Your own behalf and on Your sole responsibility, not on behalf\n    of any other Contributor, and only if You agree to indemnify,\n    defend, and hold each Contributor harmless for any liability\n    incurred by, or claims asserted against, such Contributor by reason\n    of your accepting any such warranty or additional liability.\n\nEND OF TERMS AND CONDITIONS\n\nCopyright [2024] [Jon Lunsford]\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"license.html","title":"License","type":"extras"},{"doc":"# Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"- First release.","ref":"changelog.html#v0-1-0-2024-20-05","title":"v0.1.0 (2024-20-05) - Changelog","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,50,46,50]}}